clear all
close all
%
load data_cx
%
% (X1,Y1)   => first grid for approximation with 1196 scalar samples
% (X2,Y2)   => second grid for approximation with 2501 scalar samples
% (X2,Y2x2) => second grid for approximation with 2501 2x1 samples
% (X3,Y3)   => third grid for approximation with 504 scalar samples
% (Xv,Yv)   => grid for validation with 4641 scalar samples
% (Xv,Yvx2) => grid for validation with 4641 2x1 samples
%
% Alfa angle converted from radians to degrees
X1(2,:)=X1(2,:)*57.3;
X2(2,:)=X2(2,:)*57.3;
X3(2,:)=X3(2,:)*57.3;
Xv(2,:)=Xv(2,:)*57.3;
%
maxdeg=16;                         % degree of the rational approximation (creates maxdeg/2 kernels)
koala_options.snls=-2;             % nb of iterations between SNLS stages (<0 to speed up SNLS)
koala_options.rbf=0;               % LLM type (Local Linear Model)
koala_options.Xci=X2;              % used to compute the confidence intervals
koala_options.trace=2;             % display both text and figures
koala_options.viewpoint=[-100 0];  % modify the view for 3D plots
%
% I. First call: nominal data
%
% rational approximation with koala
[fdata,fdesc,fsym,flfr,Vloo,CI]=koala(X2,Y2x2,names,maxdeg,koala_options);
%
% results display
if ~isempty(flfr), plotapprox(Xv,Yvx2,names,flfr,koala_options); end
for j=1:2
  eps=Y2x2(j,:)-fdata(j,:); sse=eps*eps'; std=sqrt(sse/length(eps)); [maxerr,kmax]=max(abs(eps));
  fprintf('Estimation errors : Global=%e  -  RMS=%e  -  Max local=%e\n',sse,std,maxerr);
  if j==1, options.viewpoint=[0 0]; else, options.viewpoint=[25 25]; end
  plosurfaces(fsym(j),X2,Y2x2(j,:),names,X2,Y2x2(j,:),Vloo(j,:),CI(j,:),options);
 end
%
% II. Second call: data are deliberately degraded 
%                  to evaluate a significant predicted variance of output errors
%                  (estimation on a rough grid & validation on a fine grid)
%
% rational approximation with koala
koala_options.Xci=Xv;
[fdata,fdesc,fsym,flfr,Vloo,CI]=koala(X3,Y3,names,maxdeg,koala_options);
%
% results display
if ~isempty(flfr), plotapprox(Xv,Yvx2,names,flfr,koala_options); end
for j=1:2
  eps=Y3(j,:)-fdata(j,:); sse=eps*eps'; std=sqrt(sse/length(eps)); [maxerr,kmax]=max(abs(eps));
  fprintf('Estimation errors : Global=%e  -  RMS=%e  -  Max local=%e\n',sse,std,maxerr);
  if j==1, options.viewpoint=[0 0]; else, options.viewpoint=[25 25]; end
  plosurfaces(fsym(j),X3,Y3(j,:),names,Xv,Yvx2(j,:),Vloo(j,:),CI(j,:),options);
end
