%%
% LSAPPROX       Polynomial approximation using Linear Least-Squares
% ------------------------------------------------------------------
%
% This routine uses  Linear Least-Squares  to compute a multivariate
% polynomial approximation y=f(x)  of a set of  n1 x n2 real samples
% yk obtained for N different  values xk of the real-valued explana-
% tory variables x. The maximum degree of the polynomial function is
% set by the user. No maximum admissible error can  be specified and
% a full polynomial expression is obtained, which minimizes the glo-
% bal relative  error and  the root-mean-square error  between f(xk)
% and yk for each entry.
%
% CALL
% [fdata,flfr]=lsapprox(X,Y,names,maxdeg,options)
%
% INPUT ARGUMENTS
% - X: values xk of the explanatory variables x  (n x N array, where
%      X(:,k) corresponds to xk).
% - Y: real samples yk  to be approximated  (n1 x n2 x N array where
%      Y(:,:,k)  corresponds to yk  in the general case, or possibly
%      1 x N array where Y(k) corresponds to yk if n1=n2=1).
% - names: names of the variables (1 x n cell array of strings).
% - maxdeg: maximum degree of the approximating polynomial function.
% - options is an optional structured variable with fields:
%   * maxexp: maximum exponent of each variable in the approximating
%             function (1 x n array, def=maxdeg*ones(1,n)).
%   * Xeq,Yeq: constraint to be  exactly met (no least squares). Yeq
%              is a n1 x n2  array and  Xeq is  a n x 1  vector with
%              associated values of the variables.
%   * trace: trace of execution (0=no, 1=text, 2=text+figs, def=1).
%   * viewpoint: deviation  with respect  to the  default  viewpoint
%                (see plotapprox, def=[0 0]). applicable only if 3-D
%                graphs are to be displayed (options.trace=2 & n=2).
%
% OUTPUT ARGUMENTS
% - fdata: values f(xk)  of the approximating  function f (same size
%          as Y).
% - flfr: linear  fractional  representation  of  the  approximating
%         function f  (gss object if  the GSS Library is  installed,
%         lfr object otherwise if the LFR Toolbox is installed).
%
% CAUTION
% If some values in X are much larger than 1, they must be scaled or
% normalized.
%
% SMAC TOOLBOX - APRICOT LIBRARY
% See http://w3.onera.fr/smac/?q=lsapprox for more info!
