function plosurfaces(fsym,estival,estidata,names,valival,validata,Vloo,varargin)

estidata=estidata';
validata=validata';
Vloo=Vloo';

prog = 'PLOSURFACES';
if size(varargin,2) > 2, error([prog ': wrong number of input arguments']); end
if size(varargin,2) == 2
 CI = varargin{1}'; options = varargin{2};
elseif size(varargin,2) == 1
 CI = varargin{1}'; options = [];
elseif size(varargin,2) == 0
 CI = []; options = [];
end

% estimation data
n2=length(unique(estival(2,:)));
n1=length(unique(estival(1,:)));
xest=reshape(estival(1,:),n2,n1)';
yest=reshape(estival(2,:),n2,n1)';
zest=reshape(estidata,n2,n1)';
% validation data
n2=length(unique(valival(2,:)));
n1=length(unique(valival(1,:)));
xval=reshape(valival(1,:),n2,n1)';
yval=reshape(valival(2,:),n2,n1)';
zval=reshape(validata,n2,n1)';

expr=char(fsym);
expr=strrep(expr,'*','.*'); expr=strrep(expr,'^','.^'); expr=strrep(expr,'/','./');
eval([names{1} '=xval;']);
eval([names{2} '=yval;']);
eval(['zapp=' expr ';']);

if isfield(options,'axlim')
 axlim=options.axlim;
 if numel(axlim)~=6
  error('PLOSURFACES: The variable options.axlim must be a 1x6 vector');
 end
 xmin=axlim(1); xmax=axlim(2); ymin=axlim(3); ymax=axlim(4); zmin=axlim(5); zmax=axlim(6); 
else
 xmin=min(min(unique(valival(1,:))));
 xmax=max(max(unique(valival(1,:))));
 ymin=min(min(unique(valival(2,:))));
 ymax=max(max(unique(valival(2,:))));
 zmin=min(validata); zmax=max(validata);
end
if isfield(options,'viewpoint')
  viewpoint=options.viewpoint;
  if numel(viewpoint)~=2
    error('PLOSURFACES: The variable options.viewpoint must be a 1x2 vector');
  end
else, viewpoint=[0 0]; end
      
fig=figure; set(fig,'Units','centimeters','Position',[1 10 20 15]);
titre=['\fontsize{14}Coefficient C=f(' names{1} ',' names{2} ')'];
subplot(2,2,1); surf(xval,yval,zval);
ax=axis; ax(1)=xmin; ax(2)=xmax; ax(3)=ymin; ax(4)=ymax; ax(5)=zmin; ax(6)=zmax;
axis(ax); view([-145 30]+viewpoint);
title(['\fontsize{18}                                  ','\fontsize{18}Coefficient Cx=f(\fontsize{22}',texlabel('alpha'),'\fontsize{18},Mach)'],'fontweight','bold');
ylabel(names{2}); xlabel(names{1}); zlabel('Validation data');

subplot(2,2,2); surf(xest,yest,zest);
ax=axis; ax(1)=xmin; ax(2)=xmax; ax(3)=ymin; ax(4)=ymax; ax(5)=zmin; ax(6)=zmax;
axis(ax); view([-145 30]+viewpoint);
ylabel(names{2}); xlabel(names{1}); zlabel('Reference data');

subplot(2,2,3); surf(xval,yval,zapp);
ax=axis; ax(1)=xmin; ax(2)=xmax; ax(3)=ymin; ax(4)=ymax; ax(5)=zmin; ax(6)=zmax;
axis(ax); view([-145 30]+viewpoint);
ylabel(names{2}); xlabel(names{1}); zlabel('Estimation data');

erreur=zapp-zval; maxerr=max(max(abs(erreur)));
subplot(2,2,4); surf(xval,yval,erreur);
ax=axis; ax(1)=xmin; ax(2)=xmax; ax(3)=ymin; ax(4)=ymax; ax(5)=-maxerr; ax(6)=maxerr;
axis(ax); view([-145 30]+viewpoint);
ylabel(names{2}); xlabel(names{1}); zlabel('Estimation error');


sse=erreur(:)'*erreur(:); std=sqrt(sse/length(erreur(:)));
fprintf('Validation errors : Global=%e  -  RMS=%e  -  Max local=%e\n',sse,std,maxerr);

fig=figure;
if ~isempty(CI)
 set(fig,'Units','centimeters','Position',[5 10 20 7]); traCI=1;
else
 set(fig,'Units','centimeters','Position',[5 10 10 7]); traCI=0;
end

n2=length(unique(valival(2,:))); n1=length(unique(valival(1,:)));
xval=reshape(valival(1,:),n2,n1)'; yval=reshape(valival(2,:),n2,n1)';

if traCI, zvar=reshape(CI,n2,n1)'; end

if isfield(options,'axlim')
 axlim=options.axlim;
 if numel(axlim)~=4
  error('PLOSURFACES: The variable options.axlim must be a 1x4 vector');
 end
 xmin=axlim(1); xmax=axlim(2); ymin=axlim(3); ymax=axlim(4);
else
 xmin=min(min(unique(valival(1,:)))); xmax=max(max(unique(valival(1,:))));
 ymin=min(min(unique(valival(2,:)))); ymax=max(max(unique(valival(2,:))));
end
if isfield(options,'viewpoint')
  viewpoint=options.viewpoint;
  if numel(viewpoint)~=2
    error('PLOSURFACES: The variable options.viewpoint must be a 1x2 vector');
  end
else, viewpoint=[0 0]; end

% Plot of LOO-type output variances on estimation data with a color map from green (lower values) to red (upper values)
Vloo=sqrt(Vloo); % to plot std and not variances
if traCI, subplot(1,2,1); end 
zmin=min(Vloo); zmax=max(Vloo); job=(Vloo-zmin)/(zmax-zmin);
for k=1:size(estival,2)
  color=(1-job(k))*[0.5 1 0] + job(k)*[1 0 0];
  plot(estival(1,k),estival(2,k),'.','MarkerSize',25,'MarkerEdgeColor',color); hold on; grid on;
end
ax=axis; ax(1)=xmin; ax(2)=xmax; ax(3)=ymin; ax(4)=ymax; axis(ax);
ylabel(names{2}); xlabel(names{1});
titre=['Estimated LOO std for output']; text(0.1,33,titre,'fontweight','bold','fontsize',14);

% Plot of Confidence Intervals on validation data
if traCI
subplot(1,2,2);
surf(xval,yval,zvar); maxerr=max(max(abs(zvar)));
ax=axis; ax(1)=xmin; ax(2)=xmax; ax(3)=ymin; ax(4)=ymax; ax(5)=0; ax(6)=maxerr;
axis(ax); view([-145 30]+viewpoint);
ylabel(names{2}); xlabel(names{1});
titre=['Confidence Interval for output']; zlabel(titre,'fontweight','bold','fontsize',14);
end
