%%
% QPAPPROX        Rational approximation using Quadratic Programming
% ------------------------------------------------------------------
%
% This routine uses Quadratic  Programming to compute a multivariate
% rational approximation y=f(x) of  a set of n1 x n2 real samples yk
% obtained for N different  values xk of the real-valued explanatory
% variables x. The  maximum degree of the rational function  and the
% maximum admissible approximation error are set by the user. A full
% rational expression  is obtained,  which ensures that the  maximum
% local absolute error between f(xk) and yk  remains below the given
% threshold  for each entry. Unless specified, its nonsingularity is
% guaranteed on the  whole considered  domain (defined as the convex
% hull of the xk).
%
% CALL
% [fdata,fdesc,fsym,flfr]=qpapprox(X,Y,names,maxdeg,maxerr,options)
%
% INPUT ARGUMENTS
% - X: values xk of the explanatory variables x  (n x N array, where
%      X(:,k) corresponds to xk).
% - Y: real samples yk  to be approximated  (n1 x n2 x N array where
%      Y(:,:,k)  corresponds to yk  in the general case, or possibly
%      1 x N array where Y(k) corresponds to yk if n1=n2=1).
% - names: names of the variables (1 x n cell array of strings).
% - maxdeg: maximum degree of the approximating function.
% - maxerr: maximum admissible  approximation  error (if  possible).
%           the local absolute error  abs(Y(k)-fdata(k)) remains be-
%           low maxerr  for each  sample 1<=k<=N and  for each entry
%           (positive number or 1 x N array).
% - options is an optional structured variable with fields:
%   * maxexp: maximum exponent of each variable in the approximating
%             function (1 x n array, def=maxdeg*ones(1,n)).
%   * postest: inclusion of  additional  constraints to  ensure that
%              the denominator  d of f is  strictly positive  on the
%              whole considered domain (0=no,  1=yes, def=1 provided
%              the GSS library or  the LFR toolbox is available). if
%              the nonsingularity of d cannot  be proved, additional
%              parameters can be tuned, see http://w3.onera.fr/smac/
%              ?q=qpapprox.
%   * trace: trace of execution (0=no, 1=text, 2=text+figs, def=1).
%   * viewpoint: deviation  with respect  to the  default  viewpoint
%                (see plotapprox, def=[0 0]). applicable only if 3-D
%                graphs are to be displayed (options.trace=2 & n=2).
%   * warn: warnings display (0=no, 1=yes, def=1).
%
% OUTPUT ARGUMENTS
% - fdata: values f(xk)  of the approximating  function f (same size
%          as Y).
% - fdesc: description of the approximating function  (fdesc{i1,i2}.
%          cnum(j)/cden(j) and fdesc{i1,i2}.enum(j,:)/eden(j,:) con-
%          tain the coefficient  and the exponents of  the jth mono-
%          mial of the numerator/denominator used to approximate en-
%          try (i1×i2) of Y). 
% - fsym: associated symbolic representation (symbolic object).
% - flfr: associated linear fractional representation (gss object if
%         the GSS Library is installed,  lfr object otherwise if the
%         LFR Toolbox is installed).
%
% CAUTION
% If some values in X are much larger than 1, they must be scaled or
% normalized.
%
% SMAC TOOLBOX - APRICOT LIBRARY
% See http://w3.onera.fr/smac/?q=qpapprox for more info!
